@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
-our $DATE = '2017-07-03'; # DATE
-our $VERSION = '0.52'; # VERSION
+our $DATE = '2017-07-04'; # DATE
+our $VERSION = '0.53'; # VERSION
 
 use 5.010001;
 use strict;
@@ -599,6 +599,8 @@ sub _gen_get_args {
                                 push @l, 'if ($mentioned_args{\'', $specmeta->{arg}, '\'}++) { push @{ $_pci_args{\'', $specmeta->{arg}, '\'} }, $_[1] } else { $_pci_args{\'', $specmeta->{arg}, '\'} = [$_[1]] }';
                             } elsif ($specmeta->{is_json}) {
                                 push @l, '$_pci_args{\'', $specmeta->{arg}, '\'} = _pci_json()->decode($_[1]);';
+                            } elsif ($specmeta->{is_neg}) {
+                                push @l, '$_pci_args{\'', $specmeta->{arg}, '\'} = 0;';
                             } else {
                                 push @l, '$_pci_args{\'', $specmeta->{arg}, '\'} = $_[1];';
                             }
@@ -1547,7 +1549,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.52 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2017-07-03.
+This document describes version 0.53 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2017-07-04.
 
 =head1 SYNOPSIS
 
